CombinedCompGCNRepresentations
==============================

.. currentmodule:: pykeen.nn.representation

.. autoclass:: CombinedCompGCNRepresentations
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~CombinedCompGCNRepresentations.forward
      ~CombinedCompGCNRepresentations.post_parameter_update
      ~CombinedCompGCNRepresentations.split
      ~CombinedCompGCNRepresentations.train

   .. rubric:: Methods Documentation

   .. automethod:: forward
   .. automethod:: post_parameter_update
   .. automethod:: split
   .. automethod:: train
